WildcardPattern class

Zero-dependency wildcard matching supporting * and ? patterns.

Constructors

WildcardPattern(String pattern, {bool caseSensitive = true})

Properties

caseSensitive bool
final
hashCode int
The hash code for this object.
no setteroverride
pattern String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String input) bool
Returns true if this pattern matches the complete input string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

anyMatch(Iterable<WildcardPattern> patterns, String input) bool
Returns true if any pattern in patterns matches the input string.