compareTo method

  1. @override
int compareTo(
  1. LineRange other
)
override

Compares this object to another object.

Returns a value like a Comparator when comparing this to other. That is, it returns a negative integer if this is ordered before other, a positive integer if this is ordered after other, and zero if this and other are ordered together.

The other argument must be a value that is comparable to this object.

Implementation

@override
int compareTo(LineRange other) {
  final startComp = startLine.compareTo(other.startLine);
  if (startComp != 0) return startComp;
  return endLine.compareTo(other.endLine);
}