MappedDeclaration class

Represents an AST declaration mapped to diff line ranges.

Constructors

MappedDeclaration({required AstNode node, required String name, required int startLine, required int endLine, required List<LineRange> intersectingRanges})
const

Properties

endLine → int
final
hashCode → int
The hash code for this object.
no setterinherited
intersectingRanges → List<LineRange>
final
name → String
final
node → AstNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLine → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited