AstLineMapper class

Utilities for mapping modified line ranges from git diffs to AST declarations.

Constructors

AstLineMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findFunctionsAndMethods(CompilationUnit unit, LineInfo lineInfo, List<LineRange> ranges) List<MappedDeclaration>
Filters mapped declarations to executable subroutines (FunctionDeclaration, MethodDeclaration, ConstructorDeclaration).
findTypes(CompilationUnit unit, LineInfo lineInfo, List<LineRange> ranges) List<MappedDeclaration>
Filters mapped declarations to top-level types (ClassDeclaration, EnumDeclaration, MixinDeclaration, ExtensionDeclaration, ExtensionTypeDeclaration, TypeAlias).
mapDeclarations(CompilationUnit unit, LineInfo lineInfo, List<LineRange> ranges, {bool includeMembers = true}) List<MappedDeclaration>
Maps ranges to enclosing declarations in unit.
mapDiffToDeclarations(CompilationUnit unit, LineInfo lineInfo, GitFileDiff fileDiff, {bool includeMembers = true}) List<MappedDeclaration>
Maps the added/modified line ranges of fileDiff to enclosing declarations in unit.