DiffHunk class
A parsed hunk within a unified diff.
Constructors
Properties
-
addedOrModifiedRanges
→ List<
LineRange> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
String> -
final
- newCount → int
-
final
- newStart → int
-
final
- oldCount → int
-
final
- oldStart → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionHeading → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited