GitDiffParser class

Parser for unified diff strings produced by git diff or diff -u.

Constructors

GitDiffParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String unifiedDiff) List<GitFileDiff>
Parses a unified diff string into a list of GitFileDiff objects.