GitFileDiff class

Represents the diff for a single file within a unified diff.

Constructors

GitFileDiff({String? oldPath, String? newPath, required List<DiffHunk> hunks, bool isNew = false, bool isDeleted = false, bool isRenamed = false})
const

Properties

addedOrModifiedLineRanges List<LineRange>
All added or modified line ranges across all hunks for this file.
no setter
hashCode int
The hash code for this object.
no setterinherited
hunks List<DiffHunk>
final
isDeleted bool
final
isNew bool
final
isRenamed bool
final
newPath String?
final
oldPath String?
final
path String
The effective relative file path for the file.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited