LineRange class

Represents a 1-based inclusive range of lines [startLine, endLine].

Implemented types

Constructors

LineRange(int startLine, int endLine)
const
LineRange.fromJson(Map<String, dynamic> json)
factory

Properties

endLine int
final
hashCode int
The hash code for this object.
no setteroverride
lineCount int
The number of lines in this range.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLine int
final

Methods

compareTo(LineRange other) int
Compares this object to another object.
override
contains(int lineNumber) bool
Returns true if lineNumber is within this range.
intersects(int start, int end) bool
Returns true if this range intersects [start, end].
intersectsRange(LineRange other) bool
Returns true if this range intersects other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override